@@ -143,3 +143,20 @@ class ProdutoEstoque(models.Model):
         verbose_name = u'Estoque do Produto'
         verbose_name_plural = u"Estoque dos Produtos"
         ordering = ['id']
+
+    def incrementar(self, quantidade=None, motivo=None):
+        """Adiciona a quantidade passada a quantidade de itens no estoque."""
+        self.quantidade = self.quantidade + quantidade
+        self.save()
+
+    def reduzir(self, quantidade=None, motivo=None, pedido_venda=None):
+        """Reduz a quantidade de itens no estoque. Caso o pedido_venda seja
+        enviado, a quantidade é descartada e o pedido_venda será usado para
+        identificar a quantidade a ser reduzida.
+        """
+        if pedido_venda:
+            pedido_item = pedido_venda.itens.get(produto=self.produto)
+            quantidade = pedido_item.quantidade
+
+        self.quantidade = self.quantidade - quantidade
+        self.save()
